from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Contacts
import win32more.Windows.ApplicationModel.DataTransfer
import win32more.Windows.ApplicationModel.DataTransfer.ShareTarget
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class IQuickLink(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink'
    _iid_ = Guid('{603e4308-f0be-4adc-acc9-8b27ab9cf556}')
    @winrt_commethod(6)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Thumbnail(self) -> win32more.Windows.Storage.Streams.RandomAccessStreamReference: ...
    @winrt_commethod(9)
    def put_Thumbnail(self, value: win32more.Windows.Storage.Streams.RandomAccessStreamReference) -> Void: ...
    @winrt_commethod(10)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_Id(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_SupportedDataFormats(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_commethod(13)
    def get_SupportedFileTypes(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    Id = property(get_Id, put_Id)
    SupportedDataFormats = property(get_SupportedDataFormats, None)
    SupportedFileTypes = property(get_SupportedFileTypes, None)
    Thumbnail = property(get_Thumbnail, put_Thumbnail)
    Title = property(get_Title, put_Title)
class IShareOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation'
    _iid_ = Guid('{2246bab8-d0f8-41c1-a82a-4137db6504fb}')
    @winrt_commethod(6)
    def get_Data(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageView: ...
    @winrt_commethod(7)
    def get_QuickLinkId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def RemoveThisQuickLink(self) -> Void: ...
    @winrt_commethod(9)
    def ReportStarted(self) -> Void: ...
    @winrt_commethod(10)
    def ReportDataRetrieved(self) -> Void: ...
    @winrt_commethod(11)
    def ReportSubmittedBackgroundTask(self) -> Void: ...
    @winrt_commethod(12)
    def ReportCompletedWithQuickLink(self, quicklink: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.QuickLink) -> Void: ...
    @winrt_commethod(13)
    def ReportCompleted(self) -> Void: ...
    @winrt_commethod(14)
    def ReportError(self, value: WinRT_String) -> Void: ...
    Data = property(get_Data, None)
    QuickLinkId = property(get_QuickLinkId, None)
class IShareOperation2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation2'
    _iid_ = Guid('{0ffb97c1-9778-4a09-8e5b-cb5e482d0555}')
    @winrt_commethod(6)
    def DismissUI(self) -> Void: ...
class IShareOperation3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation3'
    _iid_ = Guid('{5ef6b382-b7a7-4571-a2a6-994a034988b2}')
    @winrt_commethod(6)
    def get_Contacts(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Contacts.Contact]: ...
    Contacts = property(get_Contacts, None)
class QuickLink(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink
    _classid_ = 'Windows.ApplicationModel.DataTransfer.ShareTarget.QuickLink'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.QuickLink.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.QuickLink: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Thumbnail(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink) -> win32more.Windows.Storage.Streams.RandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_Thumbnail(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink, value: win32more.Windows.Storage.Streams.RandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Id(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SupportedDataFormats(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def get_SupportedFileTypes(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IQuickLink) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    Id = property(get_Id, put_Id)
    SupportedDataFormats = property(get_SupportedDataFormats, None)
    SupportedFileTypes = property(get_SupportedFileTypes, None)
    Thumbnail = property(get_Thumbnail, put_Thumbnail)
    Title = property(get_Title, put_Title)
class ShareOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation
    _classid_ = 'Windows.ApplicationModel.DataTransfer.ShareTarget.ShareOperation'
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageView: ...
    @winrt_mixinmethod
    def get_QuickLinkId(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation) -> WinRT_String: ...
    @winrt_mixinmethod
    def RemoveThisQuickLink(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation) -> Void: ...
    @winrt_mixinmethod
    def ReportStarted(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation) -> Void: ...
    @winrt_mixinmethod
    def ReportDataRetrieved(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation) -> Void: ...
    @winrt_mixinmethod
    def ReportSubmittedBackgroundTask(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation) -> Void: ...
    @winrt_mixinmethod
    def ReportCompletedWithQuickLink(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation, quicklink: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.QuickLink) -> Void: ...
    @winrt_mixinmethod
    def ReportCompleted(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation) -> Void: ...
    @winrt_mixinmethod
    def ReportError(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def DismissUI(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation2) -> Void: ...
    @winrt_mixinmethod
    def get_Contacts(self: win32more.Windows.ApplicationModel.DataTransfer.ShareTarget.IShareOperation3) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Contacts.Contact]: ...
    Contacts = property(get_Contacts, None)
    Data = property(get_Data, None)
    QuickLinkId = property(get_QuickLinkId, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Portable
import win32more.Windows.Storage
import win32more.Windows.Win32.System.WinRT
class IServiceDeviceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Portable.IServiceDeviceStatics'
    _iid_ = Guid('{a88214e1-59c7-4a20-aba6-9f6707937230}')
    @winrt_commethod(6)
    def GetDeviceSelector(self, serviceType: win32more.Windows.Devices.Portable.ServiceDeviceType) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetDeviceSelectorFromServiceId(self, serviceId: Guid) -> WinRT_String: ...
class IStorageDeviceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Portable.IStorageDeviceStatics'
    _iid_ = Guid('{5ece44ee-1b23-4dd2-8652-bc164f003128}')
    @winrt_commethod(6)
    def FromId(self, deviceId: WinRT_String) -> win32more.Windows.Storage.StorageFolder: ...
    @winrt_commethod(7)
    def GetDeviceSelector(self) -> WinRT_String: ...
PortableDeviceContract: UInt32 = 65536
class ServiceDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Portable.ServiceDevice'
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.Portable.IServiceDeviceStatics, serviceType: win32more.Windows.Devices.Portable.ServiceDeviceType) -> WinRT_String: ...
    @winrt_classmethod
    def GetDeviceSelectorFromServiceId(cls: win32more.Windows.Devices.Portable.IServiceDeviceStatics, serviceId: Guid) -> WinRT_String: ...
class ServiceDeviceType(Enum, Int32):
    CalendarService = 0
    ContactsService = 1
    DeviceStatusService = 2
    NotesService = 3
    RingtonesService = 4
    SmsService = 5
    TasksService = 6
class StorageDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Portable.StorageDevice'
    @winrt_classmethod
    def FromId(cls: win32more.Windows.Devices.Portable.IStorageDeviceStatics, deviceId: WinRT_String) -> win32more.Windows.Storage.StorageFolder: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.Portable.IStorageDeviceStatics) -> WinRT_String: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Contacts
import win32more.Windows.ApplicationModel.Contacts.Provider
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class AddContactResult(Enum, Int32):
    Added = 0
    AlreadyAdded = 1
    Unavailable = 2
class ContactPickerUI(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI
    _classid_ = 'Windows.ApplicationModel.Contacts.Provider.ContactPickerUI'
    @winrt_overload
    @winrt_mixinmethod
    def AddContact(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI, id: WinRT_String, contact: win32more.Windows.ApplicationModel.Contacts.Contact) -> win32more.Windows.ApplicationModel.Contacts.Provider.AddContactResult: ...
    @winrt_mixinmethod
    def RemoveContact(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI, id: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def ContainsContact(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI, id: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def get_DesiredFields(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI) -> win32more.Windows.ApplicationModel.Contacts.ContactSelectionMode: ...
    @winrt_mixinmethod
    def add_ContactRemoved(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.Provider.ContactPickerUI, win32more.Windows.ApplicationModel.Contacts.Provider.ContactRemovedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContactRemoved(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @AddContact.register
    @winrt_mixinmethod
    def AddContact(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI2, contact: win32more.Windows.ApplicationModel.Contacts.Contact) -> win32more.Windows.ApplicationModel.Contacts.Provider.AddContactResult: ...
    @winrt_mixinmethod
    def get_DesiredFieldsWithContactFieldType(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactPickerUI2) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.ApplicationModel.Contacts.ContactFieldType]: ...
    DesiredFields = property(get_DesiredFields, None)
    DesiredFieldsWithContactFieldType = property(get_DesiredFieldsWithContactFieldType, None)
    SelectionMode = property(get_SelectionMode, None)
    ContactRemoved = event()
class ContactRemovedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.Provider.IContactRemovedEventArgs
    _classid_ = 'Windows.ApplicationModel.Contacts.Provider.ContactRemovedEventArgs'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.ApplicationModel.Contacts.Provider.IContactRemovedEventArgs) -> WinRT_String: ...
    Id = property(get_Id, None)
class IContactPickerUI(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.Provider.IContactPickerUI'
    _iid_ = Guid('{e2cc1366-cf66-43c4-a96a-a5a112db4746}')
    @winrt_commethod(6)
    def AddContact(self, id: WinRT_String, contact: win32more.Windows.ApplicationModel.Contacts.Contact) -> win32more.Windows.ApplicationModel.Contacts.Provider.AddContactResult: ...
    @winrt_commethod(7)
    def RemoveContact(self, id: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def ContainsContact(self, id: WinRT_String) -> Boolean: ...
    @winrt_commethod(9)
    def get_DesiredFields(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(10)
    def get_SelectionMode(self) -> win32more.Windows.ApplicationModel.Contacts.ContactSelectionMode: ...
    @winrt_commethod(11)
    def add_ContactRemoved(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.Provider.ContactPickerUI, win32more.Windows.ApplicationModel.Contacts.Provider.ContactRemovedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_ContactRemoved(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DesiredFields = property(get_DesiredFields, None)
    SelectionMode = property(get_SelectionMode, None)
    ContactRemoved = event()
class IContactPickerUI2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.Provider.IContactPickerUI2'
    _iid_ = Guid('{6e449e28-7b25-4999-9b0b-875400a1e8c8}')
    @winrt_commethod(6)
    def AddContact(self, contact: win32more.Windows.ApplicationModel.Contacts.Contact) -> win32more.Windows.ApplicationModel.Contacts.Provider.AddContactResult: ...
    @winrt_commethod(7)
    def get_DesiredFieldsWithContactFieldType(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.ApplicationModel.Contacts.ContactFieldType]: ...
    DesiredFieldsWithContactFieldType = property(get_DesiredFieldsWithContactFieldType, None)
class IContactRemovedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.Provider.IContactRemovedEventArgs'
    _iid_ = Guid('{6f354338-3302-4d13-ad8d-adcc0ff9e47c}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    Id = property(get_Id, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.Communication
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.IO
MDM_COMPRESSION: UInt32 = 1
MDM_ERROR_CONTROL: UInt32 = 2
MDM_FORCED_EC: UInt32 = 4
MDM_CELLULAR: UInt32 = 8
MDM_FLOWCONTROL_HARD: UInt32 = 16
MDM_FLOWCONTROL_SOFT: UInt32 = 32
MDM_CCITT_OVERRIDE: UInt32 = 64
MDM_SPEED_ADJUST: UInt32 = 128
MDM_TONE_DIAL: UInt32 = 256
MDM_BLIND_DIAL: UInt32 = 512
MDM_V23_OVERRIDE: UInt32 = 1024
MDM_DIAGNOSTICS: UInt32 = 2048
MDM_MASK_BEARERMODE: UInt32 = 61440
MDM_SHIFT_BEARERMODE: UInt32 = 12
MDM_MASK_PROTOCOLID: UInt32 = 983040
MDM_SHIFT_PROTOCOLID: UInt32 = 16
MDM_MASK_PROTOCOLDATA: UInt32 = 267386880
MDM_SHIFT_PROTOCOLDATA: UInt32 = 20
MDM_SHIFT_PROTOCOLINFO: UInt32 = 16
MDM_SHIFT_EXTENDEDINFO: UInt32 = 12
MDM_BEARERMODE_ANALOG: UInt32 = 0
MDM_BEARERMODE_ISDN: UInt32 = 1
MDM_BEARERMODE_GSM: UInt32 = 2
MDM_PROTOCOLID_DEFAULT: UInt32 = 0
MDM_PROTOCOLID_HDLCPPP: UInt32 = 1
MDM_PROTOCOLID_V128: UInt32 = 2
MDM_PROTOCOLID_X75: UInt32 = 3
MDM_PROTOCOLID_V110: UInt32 = 4
MDM_PROTOCOLID_V120: UInt32 = 5
MDM_PROTOCOLID_AUTO: UInt32 = 6
MDM_PROTOCOLID_ANALOG: UInt32 = 7
MDM_PROTOCOLID_GPRS: UInt32 = 8
MDM_PROTOCOLID_PIAFS: UInt32 = 9
MDM_SHIFT_HDLCPPP_SPEED: UInt32 = 0
MDM_MASK_HDLCPPP_SPEED: UInt32 = 7
MDM_HDLCPPP_SPEED_DEFAULT: UInt32 = 0
MDM_HDLCPPP_SPEED_64K: UInt32 = 1
MDM_HDLCPPP_SPEED_56K: UInt32 = 2
MDM_SHIFT_HDLCPPP_AUTH: UInt32 = 3
MDM_HDLCPPP_AUTH_DEFAULT: UInt32 = 0
MDM_HDLCPPP_AUTH_NONE: UInt32 = 1
MDM_HDLCPPP_AUTH_PAP: UInt32 = 2
MDM_HDLCPPP_AUTH_CHAP: UInt32 = 3
MDM_HDLCPPP_AUTH_MSCHAP: UInt32 = 4
MDM_SHIFT_HDLCPPP_ML: UInt32 = 6
MDM_HDLCPPP_ML_DEFAULT: UInt32 = 0
MDM_HDLCPPP_ML_NONE: UInt32 = 1
MDM_HDLCPPP_ML_2: UInt32 = 2
MDM_SHIFT_V120_SPEED: UInt32 = 0
MDM_MASK_V120_SPEED: UInt32 = 7
MDM_V120_SPEED_DEFAULT: UInt32 = 0
MDM_V120_SPEED_64K: UInt32 = 1
MDM_V120_SPEED_56K: UInt32 = 2
MDM_SHIFT_V120_ML: UInt32 = 6
MDM_V120_ML_DEFAULT: UInt32 = 0
MDM_V120_ML_NONE: UInt32 = 1
MDM_V120_ML_2: UInt32 = 2
MDM_SHIFT_X75_DATA: UInt32 = 0
MDM_MASK_X75_DATA: UInt32 = 7
MDM_X75_DATA_DEFAULT: UInt32 = 0
MDM_X75_DATA_64K: UInt32 = 1
MDM_X75_DATA_128K: UInt32 = 2
MDM_X75_DATA_T_70: UInt32 = 3
MDM_X75_DATA_BTX: UInt32 = 4
MDM_SHIFT_V110_SPEED: UInt32 = 0
MDM_MASK_V110_SPEED: UInt32 = 15
MDM_V110_SPEED_DEFAULT: UInt32 = 0
MDM_V110_SPEED_1DOT2K: UInt32 = 1
MDM_V110_SPEED_2DOT4K: UInt32 = 2
MDM_V110_SPEED_4DOT8K: UInt32 = 3
MDM_V110_SPEED_9DOT6K: UInt32 = 4
MDM_V110_SPEED_12DOT0K: UInt32 = 5
MDM_V110_SPEED_14DOT4K: UInt32 = 6
MDM_V110_SPEED_19DOT2K: UInt32 = 7
MDM_V110_SPEED_28DOT8K: UInt32 = 8
MDM_V110_SPEED_38DOT4K: UInt32 = 9
MDM_V110_SPEED_57DOT6K: UInt32 = 10
MDM_SHIFT_AUTO_SPEED: UInt32 = 0
MDM_MASK_AUTO_SPEED: UInt32 = 7
MDM_AUTO_SPEED_DEFAULT: UInt32 = 0
MDM_SHIFT_AUTO_ML: UInt32 = 6
MDM_AUTO_ML_DEFAULT: UInt32 = 0
MDM_AUTO_ML_NONE: UInt32 = 1
MDM_AUTO_ML_2: UInt32 = 2
MDM_ANALOG_RLP_ON: UInt32 = 0
MDM_ANALOG_RLP_OFF: UInt32 = 1
MDM_ANALOG_V34: UInt32 = 2
MDM_PIAFS_INCOMING: UInt32 = 0
MDM_PIAFS_OUTGOING: UInt32 = 1
SID_3GPP_SUPSVCMODEL: Guid = Guid('{d7d08e07-d767-4478-b14a-eecc87ea12f7}')
MAXLENGTH_NAI: UInt32 = 72
MAXLENGTH_UICCDATASTORE: UInt32 = 10
@winfunctype('KERNEL32.dll')
def ClearCommBreak(hFile: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ClearCommError(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpErrors: POINTER(win32more.Windows.Win32.Devices.Communication.CLEAR_COMM_ERROR_FLAGS), lpStat: POINTER(win32more.Windows.Win32.Devices.Communication.COMSTAT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetupComm(hFile: win32more.Windows.Win32.Foundation.HANDLE, dwInQueue: UInt32, dwOutQueue: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EscapeCommFunction(hFile: win32more.Windows.Win32.Foundation.HANDLE, dwFunc: win32more.Windows.Win32.Devices.Communication.ESCAPE_COMM_FUNCTION) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCommConfig(hCommDev: win32more.Windows.Win32.Foundation.HANDLE, lpCC: POINTER(win32more.Windows.Win32.Devices.Communication.COMMCONFIG), lpdwSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCommMask(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpEvtMask: POINTER(win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCommProperties(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpCommProp: POINTER(win32more.Windows.Win32.Devices.Communication.COMMPROP)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCommModemStatus(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpModemStat: POINTER(win32more.Windows.Win32.Devices.Communication.MODEM_STATUS_FLAGS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCommState(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpDCB: POINTER(win32more.Windows.Win32.Devices.Communication.DCB)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCommTimeouts(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpCommTimeouts: POINTER(win32more.Windows.Win32.Devices.Communication.COMMTIMEOUTS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def PurgeComm(hFile: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: win32more.Windows.Win32.Devices.Communication.PURGE_COMM_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetCommBreak(hFile: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetCommConfig(hCommDev: win32more.Windows.Win32.Foundation.HANDLE, lpCC: POINTER(win32more.Windows.Win32.Devices.Communication.COMMCONFIG), dwSize: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetCommMask(hFile: win32more.Windows.Win32.Foundation.HANDLE, dwEvtMask: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetCommState(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpDCB: POINTER(win32more.Windows.Win32.Devices.Communication.DCB)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetCommTimeouts(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpCommTimeouts: POINTER(win32more.Windows.Win32.Devices.Communication.COMMTIMEOUTS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def TransmitCommChar(hFile: win32more.Windows.Win32.Foundation.HANDLE, cChar: win32more.Windows.Win32.Foundation.CHAR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def WaitCommEvent(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpEvtMask: POINTER(win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK), lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-core-comm-l1-1-1.dll')
def OpenCommPort(uPortNumber: UInt32, dwDesiredAccess: UInt32, dwFlagsAndAttributes: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('api-ms-win-core-comm-l1-1-2.dll')
def GetCommPorts(lpPortNumbers: POINTER(UInt32), uPortNumbersCount: UInt32, puPortNumbersFound: POINTER(UInt32)) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def BuildCommDCBA(lpDef: win32more.Windows.Win32.Foundation.PSTR, lpDCB: POINTER(win32more.Windows.Win32.Devices.Communication.DCB)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def BuildCommDCBW(lpDef: win32more.Windows.Win32.Foundation.PWSTR, lpDCB: POINTER(win32more.Windows.Win32.Devices.Communication.DCB)) -> win32more.Windows.Win32.Foundation.BOOL: ...
BuildCommDCB = UnicodeAlias('BuildCommDCBW')
@winfunctype('KERNEL32.dll')
def BuildCommDCBAndTimeoutsA(lpDef: win32more.Windows.Win32.Foundation.PSTR, lpDCB: POINTER(win32more.Windows.Win32.Devices.Communication.DCB), lpCommTimeouts: POINTER(win32more.Windows.Win32.Devices.Communication.COMMTIMEOUTS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def BuildCommDCBAndTimeoutsW(lpDef: win32more.Windows.Win32.Foundation.PWSTR, lpDCB: POINTER(win32more.Windows.Win32.Devices.Communication.DCB), lpCommTimeouts: POINTER(win32more.Windows.Win32.Devices.Communication.COMMTIMEOUTS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
BuildCommDCBAndTimeouts = UnicodeAlias('BuildCommDCBAndTimeoutsW')
@winfunctype('KERNEL32.dll')
def CommConfigDialogA(lpszName: win32more.Windows.Win32.Foundation.PSTR, hWnd: win32more.Windows.Win32.Foundation.HWND, lpCC: POINTER(win32more.Windows.Win32.Devices.Communication.COMMCONFIG)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def CommConfigDialogW(lpszName: win32more.Windows.Win32.Foundation.PWSTR, hWnd: win32more.Windows.Win32.Foundation.HWND, lpCC: POINTER(win32more.Windows.Win32.Devices.Communication.COMMCONFIG)) -> win32more.Windows.Win32.Foundation.BOOL: ...
CommConfigDialog = UnicodeAlias('CommConfigDialogW')
@winfunctype('KERNEL32.dll')
def GetDefaultCommConfigA(lpszName: win32more.Windows.Win32.Foundation.PSTR, lpCC: POINTER(win32more.Windows.Win32.Devices.Communication.COMMCONFIG), lpdwSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetDefaultCommConfigW(lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpCC: POINTER(win32more.Windows.Win32.Devices.Communication.COMMCONFIG), lpdwSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetDefaultCommConfig = UnicodeAlias('GetDefaultCommConfigW')
@winfunctype('KERNEL32.dll')
def SetDefaultCommConfigA(lpszName: win32more.Windows.Win32.Foundation.PSTR, lpCC: POINTER(win32more.Windows.Win32.Devices.Communication.COMMCONFIG), dwSize: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetDefaultCommConfigW(lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpCC: POINTER(win32more.Windows.Win32.Devices.Communication.COMMCONFIG), dwSize: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetDefaultCommConfig = UnicodeAlias('SetDefaultCommConfigW')
CLEAR_COMM_ERROR_FLAGS = UInt32
CE_BREAK: win32more.Windows.Win32.Devices.Communication.CLEAR_COMM_ERROR_FLAGS = 16
CE_FRAME: win32more.Windows.Win32.Devices.Communication.CLEAR_COMM_ERROR_FLAGS = 8
CE_OVERRUN: win32more.Windows.Win32.Devices.Communication.CLEAR_COMM_ERROR_FLAGS = 2
CE_RXOVER: win32more.Windows.Win32.Devices.Communication.CLEAR_COMM_ERROR_FLAGS = 1
CE_RXPARITY: win32more.Windows.Win32.Devices.Communication.CLEAR_COMM_ERROR_FLAGS = 4
class COMMCONFIG(Structure):
    dwSize: UInt32
    wVersion: UInt16
    wReserved: UInt16
    dcb: win32more.Windows.Win32.Devices.Communication.DCB
    dwProviderSubType: UInt32
    dwProviderOffset: UInt32
    dwProviderSize: UInt32
    wcProviderData: Char * 1
class COMMPROP(Structure):
    wPacketLength: UInt16
    wPacketVersion: UInt16
    dwServiceMask: UInt32
    dwReserved1: UInt32
    dwMaxTxQueue: UInt32
    dwMaxRxQueue: UInt32
    dwMaxBaud: UInt32
    dwProvSubType: UInt32
    dwProvCapabilities: UInt32
    dwSettableParams: UInt32
    dwSettableBaud: UInt32
    wSettableData: UInt16
    wSettableStopParity: win32more.Windows.Win32.Devices.Communication.COMMPROP_STOP_PARITY
    dwCurrentTxQueue: UInt32
    dwCurrentRxQueue: UInt32
    dwProvSpec1: UInt32
    dwProvSpec2: UInt32
    wcProvChar: Char * 1
COMMPROP_STOP_PARITY = UInt16
STOPBITS_10: win32more.Windows.Win32.Devices.Communication.COMMPROP_STOP_PARITY = 1
STOPBITS_15: win32more.Windows.Win32.Devices.Communication.COMMPROP_STOP_PARITY = 2
STOPBITS_20: win32more.Windows.Win32.Devices.Communication.COMMPROP_STOP_PARITY = 4
PARITY_NONE: win32more.Windows.Win32.Devices.Communication.COMMPROP_STOP_PARITY = 256
PARITY_ODD: win32more.Windows.Win32.Devices.Communication.COMMPROP_STOP_PARITY = 512
PARITY_EVEN: win32more.Windows.Win32.Devices.Communication.COMMPROP_STOP_PARITY = 1024
PARITY_MARK: win32more.Windows.Win32.Devices.Communication.COMMPROP_STOP_PARITY = 2048
PARITY_SPACE: win32more.Windows.Win32.Devices.Communication.COMMPROP_STOP_PARITY = 4096
class COMMTIMEOUTS(Structure):
    ReadIntervalTimeout: UInt32
    ReadTotalTimeoutMultiplier: UInt32
    ReadTotalTimeoutConstant: UInt32
    WriteTotalTimeoutMultiplier: UInt32
    WriteTotalTimeoutConstant: UInt32
COMM_EVENT_MASK = UInt32
EV_BREAK: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 64
EV_CTS: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 8
EV_DSR: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 16
EV_ERR: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 128
EV_EVENT1: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 2048
EV_EVENT2: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 4096
EV_PERR: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 512
EV_RING: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 256
EV_RLSD: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 32
EV_RX80FULL: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 1024
EV_RXCHAR: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 1
EV_RXFLAG: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 2
EV_TXEMPTY: win32more.Windows.Win32.Devices.Communication.COMM_EVENT_MASK = 4
class COMSTAT(Structure):
    fCtsHold: Annotated[UInt32, 1]
    fDsrHold: Annotated[UInt32, 1]
    fRlsdHold: Annotated[UInt32, 1]
    fXoffHold: Annotated[UInt32, 1]
    fXoffSent: Annotated[UInt32, 1]
    fEof: Annotated[UInt32, 1]
    fTxim: Annotated[UInt32, 1]
    fReserved: Annotated[UInt32, 25]
    cbInQue: UInt32
    cbOutQue: UInt32
class DCB(Structure):
    DCBlength: UInt32
    BaudRate: UInt32
    fBinary: Annotated[UInt32, 1]
    fParity: Annotated[UInt32, 1]
    fOutxCtsFlow: Annotated[UInt32, 1]
    fOutxDsrFlow: Annotated[UInt32, 1]
    fDtrControl: Annotated[UInt32, 2]
    fDsrSensitivity: Annotated[UInt32, 1]
    fTXContinueOnXoff: Annotated[UInt32, 1]
    fOutX: Annotated[UInt32, 1]
    fInX: Annotated[UInt32, 1]
    fErrorChar: Annotated[UInt32, 1]
    fNull: Annotated[UInt32, 1]
    fRtsControl: Annotated[UInt32, 2]
    fAbortOnError: Annotated[UInt32, 1]
    fDummy2: Annotated[UInt32, 17]
    wReserved: UInt16
    XonLim: UInt16
    XoffLim: UInt16
    ByteSize: Byte
    Parity: win32more.Windows.Win32.Devices.Communication.DCB_PARITY
    StopBits: win32more.Windows.Win32.Devices.Communication.DCB_STOP_BITS
    XonChar: win32more.Windows.Win32.Foundation.CHAR
    XoffChar: win32more.Windows.Win32.Foundation.CHAR
    ErrorChar: win32more.Windows.Win32.Foundation.CHAR
    EofChar: win32more.Windows.Win32.Foundation.CHAR
    EvtChar: win32more.Windows.Win32.Foundation.CHAR
    wReserved1: UInt16
DCB_PARITY = Byte
EVENPARITY: win32more.Windows.Win32.Devices.Communication.DCB_PARITY = 2
MARKPARITY: win32more.Windows.Win32.Devices.Communication.DCB_PARITY = 3
NOPARITY: win32more.Windows.Win32.Devices.Communication.DCB_PARITY = 0
ODDPARITY: win32more.Windows.Win32.Devices.Communication.DCB_PARITY = 1
SPACEPARITY: win32more.Windows.Win32.Devices.Communication.DCB_PARITY = 4
DCB_STOP_BITS = Byte
ONESTOPBIT: win32more.Windows.Win32.Devices.Communication.DCB_STOP_BITS = 0
ONE5STOPBITS: win32more.Windows.Win32.Devices.Communication.DCB_STOP_BITS = 1
TWOSTOPBITS: win32more.Windows.Win32.Devices.Communication.DCB_STOP_BITS = 2
ESCAPE_COMM_FUNCTION = UInt32
CLRBREAK: win32more.Windows.Win32.Devices.Communication.ESCAPE_COMM_FUNCTION = 9
CLRDTR: win32more.Windows.Win32.Devices.Communication.ESCAPE_COMM_FUNCTION = 6
CLRRTS: win32more.Windows.Win32.Devices.Communication.ESCAPE_COMM_FUNCTION = 4
SETBREAK: win32more.Windows.Win32.Devices.Communication.ESCAPE_COMM_FUNCTION = 8
SETDTR: win32more.Windows.Win32.Devices.Communication.ESCAPE_COMM_FUNCTION = 5
SETRTS: win32more.Windows.Win32.Devices.Communication.ESCAPE_COMM_FUNCTION = 3
SETXOFF: win32more.Windows.Win32.Devices.Communication.ESCAPE_COMM_FUNCTION = 1
SETXON: win32more.Windows.Win32.Devices.Communication.ESCAPE_COMM_FUNCTION = 2
class MODEMDEVCAPS(Structure):
    dwActualSize: UInt32
    dwRequiredSize: UInt32
    dwDevSpecificOffset: UInt32
    dwDevSpecificSize: UInt32
    dwModemProviderVersion: UInt32
    dwModemManufacturerOffset: UInt32
    dwModemManufacturerSize: UInt32
    dwModemModelOffset: UInt32
    dwModemModelSize: UInt32
    dwModemVersionOffset: UInt32
    dwModemVersionSize: UInt32
    dwDialOptions: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_DIAL_OPTIONS
    dwCallSetupFailTimer: UInt32
    dwInactivityTimeout: UInt32
    dwSpeakerVolume: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_SPEAKER_VOLUME
    dwSpeakerMode: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_SPEAKER_MODE
    dwModemOptions: UInt32
    dwMaxDTERate: UInt32
    dwMaxDCERate: UInt32
    abVariablePortion: Byte * 1
MODEMDEVCAPS_DIAL_OPTIONS = UInt32
DIALOPTION_BILLING: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_DIAL_OPTIONS = 64
DIALOPTION_DIALTONE: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_DIAL_OPTIONS = 256
DIALOPTION_QUIET: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_DIAL_OPTIONS = 128
MODEMDEVCAPS_SPEAKER_MODE = UInt32
MDMSPKRFLAG_CALLSETUP: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_SPEAKER_MODE = 8
MDMSPKRFLAG_DIAL: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_SPEAKER_MODE = 2
MDMSPKRFLAG_OFF: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_SPEAKER_MODE = 1
MDMSPKRFLAG_ON: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_SPEAKER_MODE = 4
MODEMDEVCAPS_SPEAKER_VOLUME = UInt32
MDMVOLFLAG_HIGH: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_SPEAKER_VOLUME = 4
MDMVOLFLAG_LOW: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_SPEAKER_VOLUME = 1
MDMVOLFLAG_MEDIUM: win32more.Windows.Win32.Devices.Communication.MODEMDEVCAPS_SPEAKER_VOLUME = 2
class MODEMSETTINGS(Structure):
    dwActualSize: UInt32
    dwRequiredSize: UInt32
    dwDevSpecificOffset: UInt32
    dwDevSpecificSize: UInt32
    dwCallSetupFailTimer: UInt32
    dwInactivityTimeout: UInt32
    dwSpeakerVolume: win32more.Windows.Win32.Devices.Communication.MODEM_SPEAKER_VOLUME
    dwSpeakerMode: win32more.Windows.Win32.Devices.Communication.MODEMSETTINGS_SPEAKER_MODE
    dwPreferredModemOptions: UInt32
    dwNegotiatedModemOptions: UInt32
    dwNegotiatedDCERate: UInt32
    abVariablePortion: Byte * 1
MODEMSETTINGS_SPEAKER_MODE = UInt32
MDMSPKR_CALLSETUP: win32more.Windows.Win32.Devices.Communication.MODEMSETTINGS_SPEAKER_MODE = 8
MDMSPKR_DIAL: win32more.Windows.Win32.Devices.Communication.MODEMSETTINGS_SPEAKER_MODE = 2
MDMSPKR_OFF: win32more.Windows.Win32.Devices.Communication.MODEMSETTINGS_SPEAKER_MODE = 1
MDMSPKR_ON: win32more.Windows.Win32.Devices.Communication.MODEMSETTINGS_SPEAKER_MODE = 4
MODEM_SPEAKER_VOLUME = UInt32
MDMVOL_HIGH: win32more.Windows.Win32.Devices.Communication.MODEM_SPEAKER_VOLUME = 2
MDMVOL_LOW: win32more.Windows.Win32.Devices.Communication.MODEM_SPEAKER_VOLUME = 0
MDMVOL_MEDIUM: win32more.Windows.Win32.Devices.Communication.MODEM_SPEAKER_VOLUME = 1
MODEM_STATUS_FLAGS = UInt32
MS_CTS_ON: win32more.Windows.Win32.Devices.Communication.MODEM_STATUS_FLAGS = 16
MS_DSR_ON: win32more.Windows.Win32.Devices.Communication.MODEM_STATUS_FLAGS = 32
MS_RING_ON: win32more.Windows.Win32.Devices.Communication.MODEM_STATUS_FLAGS = 64
MS_RLSD_ON: win32more.Windows.Win32.Devices.Communication.MODEM_STATUS_FLAGS = 128
PURGE_COMM_FLAGS = UInt32
PURGE_RXABORT: win32more.Windows.Win32.Devices.Communication.PURGE_COMM_FLAGS = 2
PURGE_RXCLEAR: win32more.Windows.Win32.Devices.Communication.PURGE_COMM_FLAGS = 8
PURGE_TXABORT: win32more.Windows.Win32.Devices.Communication.PURGE_COMM_FLAGS = 1
PURGE_TXCLEAR: win32more.Windows.Win32.Devices.Communication.PURGE_COMM_FLAGS = 4


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.System.RemoteDesktop.Provider
import win32more.Windows.UI
import win32more.Windows.Win32.System.WinRT
class IPerformLocalActionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.IPerformLocalActionRequestedEventArgs'
    _iid_ = Guid('{59359f4f-0862-53a3-a3b3-c932fb718cdc}')
    @winrt_commethod(6)
    def get_Action(self) -> win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopLocalAction: ...
    Action = property(get_Action, None)
class IRemoteDesktopConnectionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionInfo'
    _iid_ = Guid('{68bd69d6-6dea-543b-b737-f347919f5093}')
    @winrt_commethod(6)
    def SetConnectionStatus(self, value: win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionStatus) -> Void: ...
    @winrt_commethod(7)
    def SwitchToLocalSession(self) -> Void: ...
class IRemoteDesktopConnectionInfo2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionInfo2'
    _iid_ = Guid('{871c0b26-23bf-5d3c-bc35-a85c405e25e6}')
    @winrt_commethod(6)
    def PerformLocalActionFromRemote(self, action: win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopLocalAction) -> Void: ...
class IRemoteDesktopConnectionInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionInfoStatics'
    _iid_ = Guid('{4a7dc5a1-3368-5a75-bb78-807df7ebc439}')
    @winrt_commethod(6)
    def GetForLaunchUri(self, launchUri: win32more.Windows.Foundation.Uri, windowId: win32more.Windows.UI.WindowId) -> win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionInfo: ...
class IRemoteDesktopConnectionRemoteInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfo'
    _iid_ = Guid('{2a3dfa7e-a7ab-547e-9a6a-4c565bbb8d71}')
    @winrt_commethod(6)
    def ReportSwitched(self) -> Void: ...
    @winrt_commethod(7)
    def add_SwitchToLocalSessionRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionRemoteInfo, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_SwitchToLocalSessionRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def add_PerformLocalActionRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionRemoteInfo, win32more.Windows.System.RemoteDesktop.Provider.PerformLocalActionRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_PerformLocalActionRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    SwitchToLocalSessionRequested = event()
    PerformLocalActionRequested = event()
class IRemoteDesktopConnectionRemoteInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfoStatics'
    _iid_ = Guid('{b590e64a-e4c9-53e8-b83d-a0db3676246a}')
    @winrt_commethod(6)
    def IsSwitchSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def GetForLaunchUri(self, launchUri: win32more.Windows.Foundation.Uri) -> win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionRemoteInfo: ...
class IRemoteDesktopInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.IRemoteDesktopInfo'
    _iid_ = Guid('{d185bb25-2f1e-5098-b9e0-f46d6358c5c4}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Id(self) -> WinRT_String: ...
    DisplayName = property(get_DisplayName, None)
    Id = property(get_Id, None)
class IRemoteDesktopInfoFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.IRemoteDesktopInfoFactory'
    _iid_ = Guid('{ad0e8d58-b56f-5a8b-b419-8002ee0c5ee9}')
    @winrt_commethod(6)
    def CreateInstance(self, id: WinRT_String, displayName: WinRT_String) -> win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopInfo: ...
class IRemoteDesktopRegistrarStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.IRemoteDesktopRegistrarStatics'
    _iid_ = Guid('{687c2750-46d9-5de3-8dc3-84a9202cecfb}')
    @winrt_commethod(6)
    def get_DesktopInfos(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopInfo]: ...
    @winrt_commethod(7)
    def IsSwitchToLocalSessionEnabled(self) -> Boolean: ...
    DesktopInfos = property(get_DesktopInfos, None)
class PerformLocalActionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.RemoteDesktop.Provider.IPerformLocalActionRequestedEventArgs
    _classid_ = 'Windows.System.RemoteDesktop.Provider.PerformLocalActionRequestedEventArgs'
    @winrt_mixinmethod
    def get_Action(self: win32more.Windows.System.RemoteDesktop.Provider.IPerformLocalActionRequestedEventArgs) -> win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopLocalAction: ...
    Action = property(get_Action, None)
class RemoteDesktopConnectionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionInfo
    _classid_ = 'Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionInfo'
    @winrt_mixinmethod
    def SetConnectionStatus(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionInfo, value: win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionStatus) -> Void: ...
    @winrt_mixinmethod
    def SwitchToLocalSession(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionInfo) -> Void: ...
    @winrt_mixinmethod
    def PerformLocalActionFromRemote(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionInfo2, action: win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopLocalAction) -> Void: ...
    @winrt_classmethod
    def GetForLaunchUri(cls: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionInfoStatics, launchUri: win32more.Windows.Foundation.Uri, windowId: win32more.Windows.UI.WindowId) -> win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionInfo: ...
class RemoteDesktopConnectionRemoteInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfo
    _classid_ = 'Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionRemoteInfo'
    @winrt_mixinmethod
    def ReportSwitched(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfo) -> Void: ...
    @winrt_mixinmethod
    def add_SwitchToLocalSessionRequested(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfo, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionRemoteInfo, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SwitchToLocalSessionRequested(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PerformLocalActionRequested(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfo, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionRemoteInfo, win32more.Windows.System.RemoteDesktop.Provider.PerformLocalActionRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PerformLocalActionRequested(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def IsSwitchSupported(cls: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfoStatics) -> Boolean: ...
    @winrt_classmethod
    def GetForLaunchUri(cls: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopConnectionRemoteInfoStatics, launchUri: win32more.Windows.Foundation.Uri) -> win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopConnectionRemoteInfo: ...
    SwitchToLocalSessionRequested = event()
    PerformLocalActionRequested = event()
class RemoteDesktopConnectionStatus(Enum, Int32):
    Connecting = 0
    Connected = 1
    UserInputNeeded = 2
    Disconnected = 3
class RemoteDesktopInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopInfo
    _classid_ = 'Windows.System.RemoteDesktop.Provider.RemoteDesktopInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopInfo.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopInfoFactory, id: WinRT_String, displayName: WinRT_String) -> win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopInfo: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopInfo) -> WinRT_String: ...
    DisplayName = property(get_DisplayName, None)
    Id = property(get_Id, None)
class RemoteDesktopLocalAction(Enum, Int32):
    ShowBluetoothSettings = 0
    ShowSystemSoundSettings = 1
    ShowSystemDisplaySettings = 2
    ShowSystemAccountSettings = 3
    ShowLocalSettings = 4
class _RemoteDesktopRegistrar_Meta_(ComPtr.__class__):
    pass
class RemoteDesktopRegistrar(ComPtr, metaclass=_RemoteDesktopRegistrar_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.RemoteDesktop.Provider.RemoteDesktopRegistrar'
    @winrt_classmethod
    def get_DesktopInfos(cls: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopRegistrarStatics) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.System.RemoteDesktop.Provider.RemoteDesktopInfo]: ...
    @winrt_classmethod
    def IsSwitchToLocalSessionEnabled(cls: win32more.Windows.System.RemoteDesktop.Provider.IRemoteDesktopRegistrarStatics) -> Boolean: ...
    _RemoteDesktopRegistrar_Meta_.DesktopInfos = property(get_DesktopInfos, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Media.DxMediaObjects
import win32more.Windows.Win32.System.Com
DMO_E_INVALIDSTREAMINDEX: win32more.Windows.Win32.Foundation.HRESULT = -2147220991
DMO_E_INVALIDTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147220990
DMO_E_TYPE_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2147220989
DMO_E_NOTACCEPTING: win32more.Windows.Win32.Foundation.HRESULT = -2147220988
DMO_E_TYPE_NOT_ACCEPTED: win32more.Windows.Win32.Foundation.HRESULT = -2147220987
DMO_E_NO_MORE_ITEMS: win32more.Windows.Win32.Foundation.HRESULT = -2147220986
DMOCATEGORY_AUDIO_DECODER: Guid = Guid('{57f2db8b-e6bb-4513-9d43-dcd2a6593125}')
DMOCATEGORY_AUDIO_ENCODER: Guid = Guid('{33d9a761-90c8-11d0-bd43-00a0c911ce86}')
DMOCATEGORY_VIDEO_DECODER: Guid = Guid('{4a69b442-28be-4991-969c-b500adf5d8a8}')
DMOCATEGORY_VIDEO_ENCODER: Guid = Guid('{33d9a760-90c8-11d0-bd43-00a0c911ce86}')
DMOCATEGORY_AUDIO_EFFECT: Guid = Guid('{f3602b3f-0592-48df-a4cd-674721e7ebeb}')
DMOCATEGORY_VIDEO_EFFECT: Guid = Guid('{d990ee14-776c-4723-be46-3da2f56f10b9}')
DMOCATEGORY_AUDIO_CAPTURE_EFFECT: Guid = Guid('{f665aaba-3e09-4920-aa5f-219811148f09}')
DMOCATEGORY_ACOUSTIC_ECHO_CANCEL: Guid = Guid('{bf963d80-c559-11d0-8a2b-00a0c9255ac1}')
DMOCATEGORY_AUDIO_NOISE_SUPPRESS: Guid = Guid('{e07f903f-62fd-4e60-8cdd-dea7236665b5}')
DMOCATEGORY_AGC: Guid = Guid('{e88c9ba0-c557-11d0-8a2b-00a0c9255ac1}')
@winfunctype('msdmo.dll')
def DMORegister(szName: win32more.Windows.Win32.Foundation.PWSTR, clsidDMO: POINTER(Guid), guidCategory: POINTER(Guid), dwFlags: UInt32, cInTypes: UInt32, pInTypes: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_PARTIAL_MEDIATYPE), cOutTypes: UInt32, pOutTypes: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_PARTIAL_MEDIATYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def DMOUnregister(clsidDMO: POINTER(Guid), guidCategory: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def DMOEnum(guidCategory: POINTER(Guid), dwFlags: UInt32, cInTypes: UInt32, pInTypes: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_PARTIAL_MEDIATYPE), cOutTypes: UInt32, pOutTypes: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_PARTIAL_MEDIATYPE), ppEnum: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.IEnumDMO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def DMOGetTypes(clsidDMO: POINTER(Guid), ulInputTypesRequested: UInt32, pulInputTypesSupplied: POINTER(UInt32), pInputTypes: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_PARTIAL_MEDIATYPE), ulOutputTypesRequested: UInt32, pulOutputTypesSupplied: POINTER(UInt32), pOutputTypes: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_PARTIAL_MEDIATYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def DMOGetName(clsidDMO: POINTER(Guid), szName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def MoInitMediaType(pmt: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE), cbFormat: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def MoFreeMediaType(pmt: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def MoCopyMediaType(pmtDest: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE), pmtSrc: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def MoCreateMediaType(ppmt: POINTER(POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)), cbFormat: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def MoDeleteMediaType(pmt: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdmo.dll')
def MoDuplicateMediaType(ppmtDest: POINTER(POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)), pmtSrc: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DMO_ENUM_FLAGS = Int32
DMO_ENUMF_INCLUDE_KEYED: win32more.Windows.Win32.Media.DxMediaObjects.DMO_ENUM_FLAGS = 1
class DMO_MEDIA_TYPE(Structure):
    majortype: Guid
    subtype: Guid
    bFixedSizeSamples: win32more.Windows.Win32.Foundation.BOOL
    bTemporalCompression: win32more.Windows.Win32.Foundation.BOOL
    lSampleSize: UInt32
    formattype: Guid
    pUnk: win32more.Windows.Win32.System.Com.IUnknown
    cbFormat: UInt32
    pbFormat: POINTER(Byte)
class DMO_OUTPUT_DATA_BUFFER(Structure):
    pBuffer: win32more.Windows.Win32.Media.DxMediaObjects.IMediaBuffer
    dwStatus: UInt32
    rtTimestamp: Int64
    rtTimelength: Int64
class DMO_PARTIAL_MEDIATYPE(Structure):
    type: Guid
    subtype: Guid
DMO_REGISTER_FLAGS = Int32
DMO_REGISTERF_IS_KEYED: win32more.Windows.Win32.Media.DxMediaObjects.DMO_REGISTER_FLAGS = 1
class IDMOQualityControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{65abea96-cf36-453f-af8a-705e98f16260}')
    @commethod(3)
    def SetNow(self, rtNow: Int64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetStatus(self, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetStatus(self, pdwFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDMOVideoOutputOptimizations(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{be8f4f4e-5b16-4d29-b350-7f6b5d9298ac}')
    @commethod(3)
    def QueryOperationModePreferences(self, ulOutputStreamIndex: UInt32, pdwRequestedCapabilities: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetOperationMode(self, ulOutputStreamIndex: UInt32, dwEnabledFeatures: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrentOperationMode(self, ulOutputStreamIndex: UInt32, pdwEnabledFeatures: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetCurrentSampleRequirements(self, ulOutputStreamIndex: UInt32, pdwRequestedFeatures: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumDMO(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2c3cd98a-2bfa-4a53-9c27-5249ba64ba0f}')
    @commethod(3)
    def Next(self, cItemsToFetch: UInt32, pCLSID: POINTER(Guid), Names: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcItemsFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, cItemsToSkip: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppEnum: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.IEnumDMO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMediaBuffer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{59eff8b9-938c-4a26-82f2-95cb84cdc837}')
    @commethod(3)
    def SetLength(self, cbLength: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetMaxLength(self, pcbMaxLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetBufferAndLength(self, ppBuffer: POINTER(POINTER(Byte)), pcbLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMediaObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d8ad0f58-5494-4102-97c5-ec798e59bcf4}')
    @commethod(3)
    def GetStreamCount(self, pcInputStreams: POINTER(UInt32), pcOutputStreams: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetInputStreamInfo(self, dwInputStreamIndex: UInt32, pdwFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetOutputStreamInfo(self, dwOutputStreamIndex: UInt32, pdwFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetInputType(self, dwInputStreamIndex: UInt32, dwTypeIndex: UInt32, pmt: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetOutputType(self, dwOutputStreamIndex: UInt32, dwTypeIndex: UInt32, pmt: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetInputType(self, dwInputStreamIndex: UInt32, pmt: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetOutputType(self, dwOutputStreamIndex: UInt32, pmt: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetInputCurrentType(self, dwInputStreamIndex: UInt32, pmt: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOutputCurrentType(self, dwOutputStreamIndex: UInt32, pmt: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetInputSizeInfo(self, dwInputStreamIndex: UInt32, pcbSize: POINTER(UInt32), pcbMaxLookahead: POINTER(UInt32), pcbAlignment: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetOutputSizeInfo(self, dwOutputStreamIndex: UInt32, pcbSize: POINTER(UInt32), pcbAlignment: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetInputMaxLatency(self, dwInputStreamIndex: UInt32, prtMaxLatency: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetInputMaxLatency(self, dwInputStreamIndex: UInt32, rtMaxLatency: Int64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Flush(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Discontinuity(self, dwInputStreamIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def AllocateStreamingResources(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def FreeStreamingResources(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetInputStatus(self, dwInputStreamIndex: UInt32, dwFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ProcessInput(self, dwInputStreamIndex: UInt32, pBuffer: win32more.Windows.Win32.Media.DxMediaObjects.IMediaBuffer, dwFlags: UInt32, rtTimestamp: Int64, rtTimelength: Int64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ProcessOutput(self, dwFlags: UInt32, cOutputBufferCount: UInt32, pOutputBuffers: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.DMO_OUTPUT_DATA_BUFFER), pdwStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Lock(self, bLock: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMediaObjectInPlace(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{651b9ad0-0fc7-4aa9-9538-d89931010741}')
    @commethod(3)
    def Process(self, ulSize: UInt32, pData: POINTER(Byte), refTimeStart: Int64, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Clone(self, ppMediaObject: POINTER(win32more.Windows.Win32.Media.DxMediaObjects.IMediaObjectInPlace)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetLatency(self, pLatencyTime: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
_DMO_INPLACE_PROCESS_FLAGS = Int32
DMO_INPLACE_NORMAL: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPLACE_PROCESS_FLAGS = 0
DMO_INPLACE_ZERO: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPLACE_PROCESS_FLAGS = 1
_DMO_INPUT_DATA_BUFFER_FLAGS = Int32
DMO_INPUT_DATA_BUFFERF_SYNCPOINT: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPUT_DATA_BUFFER_FLAGS = 1
DMO_INPUT_DATA_BUFFERF_TIME: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPUT_DATA_BUFFER_FLAGS = 2
DMO_INPUT_DATA_BUFFERF_TIMELENGTH: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPUT_DATA_BUFFER_FLAGS = 4
DMO_INPUT_DATA_BUFFERF_DISCONTINUITY: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPUT_DATA_BUFFER_FLAGS = 8
_DMO_INPUT_STATUS_FLAGS = Int32
DMO_INPUT_STATUSF_ACCEPT_DATA: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPUT_STATUS_FLAGS = 1
_DMO_INPUT_STREAM_INFO_FLAGS = Int32
DMO_INPUT_STREAMF_WHOLE_SAMPLES: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPUT_STREAM_INFO_FLAGS = 1
DMO_INPUT_STREAMF_SINGLE_SAMPLE_PER_BUFFER: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPUT_STREAM_INFO_FLAGS = 2
DMO_INPUT_STREAMF_FIXED_SAMPLE_SIZE: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPUT_STREAM_INFO_FLAGS = 4
DMO_INPUT_STREAMF_HOLDS_BUFFERS: win32more.Windows.Win32.Media.DxMediaObjects._DMO_INPUT_STREAM_INFO_FLAGS = 8
_DMO_OUTPUT_DATA_BUFFER_FLAGS = Int32
DMO_OUTPUT_DATA_BUFFERF_SYNCPOINT: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_DATA_BUFFER_FLAGS = 1
DMO_OUTPUT_DATA_BUFFERF_TIME: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_DATA_BUFFER_FLAGS = 2
DMO_OUTPUT_DATA_BUFFERF_TIMELENGTH: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_DATA_BUFFER_FLAGS = 4
DMO_OUTPUT_DATA_BUFFERF_DISCONTINUITY: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_DATA_BUFFER_FLAGS = 8
DMO_OUTPUT_DATA_BUFFERF_INCOMPLETE: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_DATA_BUFFER_FLAGS = 16777216
_DMO_OUTPUT_STREAM_INFO_FLAGS = Int32
DMO_OUTPUT_STREAMF_WHOLE_SAMPLES: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_STREAM_INFO_FLAGS = 1
DMO_OUTPUT_STREAMF_SINGLE_SAMPLE_PER_BUFFER: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_STREAM_INFO_FLAGS = 2
DMO_OUTPUT_STREAMF_FIXED_SAMPLE_SIZE: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_STREAM_INFO_FLAGS = 4
DMO_OUTPUT_STREAMF_DISCARDABLE: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_STREAM_INFO_FLAGS = 8
DMO_OUTPUT_STREAMF_OPTIONAL: win32more.Windows.Win32.Media.DxMediaObjects._DMO_OUTPUT_STREAM_INFO_FLAGS = 16
_DMO_PROCESS_OUTPUT_FLAGS = Int32
DMO_PROCESS_OUTPUT_DISCARD_WHEN_NO_BUFFER: win32more.Windows.Win32.Media.DxMediaObjects._DMO_PROCESS_OUTPUT_FLAGS = 1
_DMO_QUALITY_STATUS_FLAGS = Int32
DMO_QUALITY_STATUS_ENABLED: win32more.Windows.Win32.Media.DxMediaObjects._DMO_QUALITY_STATUS_FLAGS = 1
_DMO_SET_TYPE_FLAGS = Int32
DMO_SET_TYPEF_TEST_ONLY: win32more.Windows.Win32.Media.DxMediaObjects._DMO_SET_TYPE_FLAGS = 1
DMO_SET_TYPEF_CLEAR: win32more.Windows.Win32.Media.DxMediaObjects._DMO_SET_TYPE_FLAGS = 2
_DMO_VIDEO_OUTPUT_STREAM_FLAGS = Int32
DMO_VOSF_NEEDS_PREVIOUS_SAMPLE: win32more.Windows.Win32.Media.DxMediaObjects._DMO_VIDEO_OUTPUT_STREAM_FLAGS = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.PasswordManagement
@winfunctype('ADVAPI32.dll')
def MSChapSrvChangePassword(ServerName: win32more.Windows.Win32.Foundation.PWSTR, UserName: win32more.Windows.Win32.Foundation.PWSTR, LmOldPresent: win32more.Windows.Win32.Foundation.BOOLEAN, LmOldOwfPassword: POINTER(win32more.Windows.Win32.System.PasswordManagement.LM_OWF_PASSWORD), LmNewOwfPassword: POINTER(win32more.Windows.Win32.System.PasswordManagement.LM_OWF_PASSWORD), NtOldOwfPassword: POINTER(win32more.Windows.Win32.System.PasswordManagement.LM_OWF_PASSWORD), NtNewOwfPassword: POINTER(win32more.Windows.Win32.System.PasswordManagement.LM_OWF_PASSWORD)) -> UInt32: ...
@winfunctype('ADVAPI32.dll')
def MSChapSrvChangePassword2(ServerName: win32more.Windows.Win32.Foundation.PWSTR, UserName: win32more.Windows.Win32.Foundation.PWSTR, NewPasswordEncryptedWithOldNt: POINTER(win32more.Windows.Win32.System.PasswordManagement.SAMPR_ENCRYPTED_USER_PASSWORD), OldNtOwfPasswordEncryptedWithNewNt: POINTER(win32more.Windows.Win32.System.PasswordManagement.ENCRYPTED_LM_OWF_PASSWORD), LmPresent: win32more.Windows.Win32.Foundation.BOOLEAN, NewPasswordEncryptedWithOldLm: POINTER(win32more.Windows.Win32.System.PasswordManagement.SAMPR_ENCRYPTED_USER_PASSWORD), OldLmOwfPasswordEncryptedWithNewLmOrNt: POINTER(win32more.Windows.Win32.System.PasswordManagement.ENCRYPTED_LM_OWF_PASSWORD)) -> UInt32: ...
class CYPHER_BLOCK(Structure):
    data: win32more.Windows.Win32.Foundation.CHAR * 8
class ENCRYPTED_LM_OWF_PASSWORD(Structure):
    data: win32more.Windows.Win32.System.PasswordManagement.CYPHER_BLOCK * 2
class LM_OWF_PASSWORD(Structure):
    data: win32more.Windows.Win32.System.PasswordManagement.CYPHER_BLOCK * 2
class SAMPR_ENCRYPTED_USER_PASSWORD(Structure):
    Buffer: Byte * 516


make_ready(__name__)
